@@ -1,36 +1,24 @@
 package My::Build::Win32_MSVC_Bakefile;
 
 use strict;
-use base qw(My::Build::Win32_MSVC My::Build::Win32_Bakefile);
+use base qw(My::Build::Win32_MSVC);
 use My::Build::Utility qw(awx_install_arch_file awx_install_arch_auto_file);
-use Alien::wxWidgets::Utility qw(awx_capture);
 use Config;
 use Fatal qw(chdir);
-use Cwd ();
 
-sub _check_nmake {
-    my $out = awx_capture( 'nmake /?' );
-    unless( $out =~ m{/U\s}i ) {
-        die "Please use an NMAKE version supporting '-u', not the" .
-            " freely-available one\n";
-    }
-}
+my $min_dir = File::Spec->catdir( $ENV{WXDIR}, 'samples', 'minimal' );
 
 sub awx_wx_config_data {
     my $self = shift;
-
-    My::Build::Win32::_init();
-    $self->_check_nmake();
-
     return $self->{awx_data} if $self->{awx_data};
 
     my %data = ( %{$self->SUPER::awx_wx_config_data},
                  'cxx'     => 'cl',
                  'ld'      => 'link',
+                 'wxdir'   => $ENV{WXDIR},
                );
 
-    my $make =  File::Basename::basename( lc $Config{make}, '.exe' );
-    die "PANIC: you are not using nmake!" unless $make eq 'nmake';
+    die "PANIC: you are not using nmake!" unless $Config{make} eq 'nmake';
 
     my $orig_libdir;
     my $final = $self->awx_debug ? 'BUILD=debug   DEBUG_RUNTIME_LIBS=0'
@@ -39,9 +27,8 @@ sub awx_wx_config_data {
     $unicode .= ' MSLU=1' if $self->awx_mslu;
 
     my $dir = Cwd::cwd;
-    chdir File::Spec->catdir( $ENV{WXDIR}, 'samples', 'minimal' );
-    my $extraflags = $self->notes( 'extraflags');
-    my @t = qx(nmake /nologo /n /a /u /f makefile.vc $final $unicode SHARED=1 $extraflags);
+    chdir $min_dir;
+    my @t = qx(nmake /nologo /n /u /f makefile.vc $final $unicode SHARED=1);
 
     my( $accu, $libdir, $digits );
     foreach ( @t ) {
@@ -55,7 +42,7 @@ sub awx_wx_config_data {
             s{[-/]LIBPATH:(\S+)}
              {$orig_libdir = File::Spec->canonpath
                                  ( File::Spec->rel2abs( $1 ) );
-              '-L' . ( $libdir = awx_install_arch_file( $self, 'rEpLaCe/lib' ) )}egi;
+              '-L' . ( $libdir = awx_install_arch_file( 'rEpLaCe/lib' ) )}egi;
             $data{libs} = $_;
         } elsif( s/^\s*cl\s+// ) {
             s/\s+\S+\.(cpp|pdb|obj)/ /g;
@@ -71,34 +58,10 @@ sub awx_wx_config_data {
     chdir $dir;
     die 'Could not find wxWidgets lib directory' unless $libdir;
 
-    $self->awx_w32_find_setup_dir( $data{cxxflags} ); # for awx_grep_dlls
-
-    $data{dlls} = $self->awx_grep_dlls( $orig_libdir, $digits, $self->awx_is_monolithic );
+    $data{dlls} = $self->awx_grep_dlls( $orig_libdir, $digits );
     $data{version} = $digits;
 
     $self->{awx_data} = \%data;
 }
 
-sub _make_command { "nmake -f makefile.vc all " }
-
-sub build_wxwidgets {
-    my( $self ) = shift;
-    my $old_dir = Cwd::cwd();
-
-    $self->My::Build::Win32_Bakefile::build_wxwidgets( @_ );
-
-    # Compiling with MSVC 9 (VS 2008) and probably with VS 2005, the
-    # linker creates a manifest that must be embedded in the DLL to
-    # make it load correctly
-    chdir File::Spec->catdir( $ENV{WXDIR} );
-    foreach my $dll ( glob( 'lib/vc_dll*/*.dll' ) ) {
-        next unless -f "${dll}.manifest";
-        $self->_system( 'mt', '-nologo', '-manifest', "${dll}.manifest",
-                        "-outputresource:${dll};2" );
-        unlink "${dll}.manifest";
-    }
-
-    chdir $old_dir;
-}
-
 1;
