@@ -1,33 +1,31 @@
 package My::Build::Win32_MinGW_Bakefile;
 
 use strict;
-use base qw(My::Build::Win32_MinGW My::Build::Win32_Bakefile);
+use base qw(My::Build::Win32_MinGW);
 use My::Build::Utility qw(awx_install_arch_file awx_install_arch_auto_file);
 use Config;
 use Fatal qw(chdir);
 
-sub awx_wx_config_data {
-    My::Build::Win32::_init();
+my $min_dir = File::Spec->catdir( $ENV{WXDIR}, 'samples', 'minimal' );
 
+sub awx_wx_config_data {
     my $self = shift;
     return $self->{awx_data} if $self->{awx_data};
 
     my %data = ( %{$self->SUPER::awx_wx_config_data},
                  'cxx'     => 'g++',
                  'ld'      => 'g++',
+                 'wxdir'   => $ENV{WXDIR},
                );
 
-    my $cflags = 'CXXFLAGS=" -Os -DNO_GCC_PRAGMA "';
     my $final = $self->awx_debug ? 'BUILD=debug'
                                  : 'BUILD=release';
     my $unicode = $self->awx_unicode ? 'UNICODE=1' : 'UNICODE=0';
     $unicode .= ' MSLU=1' if $self->awx_mslu;
 
     my $dir = Cwd::cwd;
-    my $make = $self->_find_make;
-    chdir File::Spec->catdir( $ENV{WXDIR}, 'samples', 'minimal' );
-    my $extraflags = $self->notes( 'extraflags');
-    my @t = qx($make -n -B -f makefile.gcc $final $unicode $cflags SHARED=1 $extraflags);
+    chdir $min_dir;
+    my @t = qx(make -n -f makefile.gcc $final $unicode SHARED=1);
 
     my( $orig_libdir, $libdir, $digits );
     foreach ( @t ) {
@@ -41,11 +39,10 @@ sub awx_wx_config_data {
             s{-L(\S+)}
              {$orig_libdir = File::Spec->canonpath
                                  ( File::Spec->rel2abs( $1 ) );
-              '-L' . ( $libdir = awx_install_arch_file( $self, 'rEpLaCe/lib' ) )}eg;
+              '-L' . ( $libdir = awx_install_arch_file( 'rEpLaCe/lib' ) )}eg;
             $data{libs} = $_;
         } elsif( s/^\s*g\+\+\s+// ) {
-            s/\s+\S+\.(cpp|o|d)/ /g;
-            s/\s+-M[DP]\b/ /g;
+            s/\s+\S+\.(cpp|o)/ /g;
             s/(?:\s|^)-[co]//g;
             s{[-/]I(\S+)}{'-I' . File::Spec->canonpath
                                      ( File::Spec->rel2abs( $1 ) )}egi;
@@ -58,23 +55,10 @@ sub awx_wx_config_data {
     chdir $dir;
     die 'Could not find wxWidgets lib directory' unless $libdir;
 
-    $self->awx_w32_find_setup_dir( $data{cxxflags} ); # for awx_grep_dlls
-
-    $data{dlls} = $self->awx_grep_dlls( $orig_libdir, $digits, $self->awx_is_monolithic );
+    $data{dlls} = $self->awx_grep_dlls( $orig_libdir, $digits );
     $data{version} = $digits;
 
     $self->{awx_data} = \%data;
 }
 
-sub _make_command {
-    my $make = $_[0]->_find_make;
-    "$make -f makefile.gcc all "
-}
-
-sub build_wxwidgets {
-    my( $self ) = shift;
-
-    $self->My::Build::Win32_Bakefile::build_wxwidgets( @_ );
-}
-
 1;
